# ETE Tree Explorer

This is a tool for exploring trees. It is mainly used to explore phylogenetic trees, but it can be used for any kind of tree.

You can explore the pre-loaded trees, or add your own trees for exploration by uploading them from this page.

The tree can be written in the newick format or a depth-indented listing (like the output of the `tree` program).

When using the interactive gui for exploration, press `F1` or the help button in the viewer for instructions.

Tree
From string (load an example)
From file:
How to parse
`((name:dist)name:dist);` (newick with internal node name)
`((name:dist)support:dist);` (newick with internal node support)
Depth-indented listing
Add name
Name (1 to 128 characters)